@@ -14,7 +14,7 @@ class Task:
     ASSIGNED_TO_HUMAN = "human"
     ASSIGNED_TO_ROBOT = "robot"
 
-    def __init__(self, uuid: str, name: str, product_uuid: str, pose: Pose, automated: bool = False,
+    def __init__(self, uuid: str, name: str, product_uuid: str, pose: Pose, agents: List[str],
                  assigned_to: str = ASSIGNED_TO_HUMAN, conditions: List[str] = None, conditions_fulfilled: bool = True,
                  can_undo: bool = False, description: str = "", status: str = '', _type: str = ''):
         conditions = conditions if conditions else []
@@ -23,7 +23,7 @@ class Task:
         assert type(name) == str
         assert type(product_uuid) == str
         assert type(pose) == Pose
-        assert type(automated) == bool
+        assert type(agents) == list
         assert type(assigned_to) == str
         assert type(conditions) == list, f"Expected list type. Type of conditions: {type(conditions)}"
         assert type(conditions_fulfilled) == bool
@@ -36,7 +36,7 @@ class Task:
         self.name = name
         self.product_uuid = product_uuid
         self.pose = pose
-        self.automated = automated
+        self.agents = agents
         self.assigned_to = assigned_to
         self.conditions = conditions
         self.conditions_fulfilled = conditions_fulfilled
@@ -49,7 +49,7 @@ class Task:
             return other.uuid == self.uuid \
                    and other.product_uuid == self.product_uuid \
                    and other.pose == self.pose \
-                   and other.automated == self.automated \
+                   and other.agents == self.agents \
                    and other.assigned_to == self.assigned_to \
                    and other.conditions == self.conditions \
                    and other.conditions_fulfilled == self.conditions_fulfilled \
@@ -63,7 +63,7 @@ class Task:
 
     def __repr__(self):
         return f"<uuid={self.uuid},name={self.name},product_uuid={self.product_uuid},pose={self.pose}," \
-               f"automated={self.automated},assigned_to={self.assigned_to},conditions={self.conditions}," \
+               f"agents={self.agents},assigned_to={self.assigned_to},conditions={self.conditions}," \
                f"status={self.status},conditions_fulfilled={self.conditions_fulfilled},can_undo={self.can_undo}," \
                f"description={self.description}>"
 
